.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to hckr's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cron
   info
   hello

Indices and tables
-------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. click:: hckr.cli:cli
   :prog: hckr
   :nested: short
